"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = inject;

var _universalEnv = require("universal-env");

var _host = _interopRequireDefault(require("./vdom/host"));

var _empty = _interopRequireDefault(require("./vdom/empty"));

var _native = _interopRequireDefault(require("./vdom/native"));

var _text = _interopRequireDefault(require("./vdom/text"));

var _composite = _interopRequireDefault(require("./vdom/composite"));

var _fragment = _interopRequireDefault(require("./vdom/fragment"));

var _driverWeex = _interopRequireDefault(require("driver-weex"));

var _driverBrowser = _interopRequireDefault(require("driver-browser"));

var _hook = _interopRequireDefault(require("./debug/hook"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function inject(_ref) {
  var driver = _ref.driver,
      hook = _ref.hook,
      measurer = _ref.measurer,
      deviceWidth = _ref.deviceWidth,
      viewportWidth = _ref.viewportWidth,
      eventRegistry = _ref.eventRegistry,
      bodyType = _ref.bodyType,
      bodyProps = _ref.bodyProps;
  // Inject component class
  _host.default.EmptyComponent = _empty.default;
  _host.default.NativeComponent = _native.default;
  _host.default.TextComponent = _text.default;
  _host.default.FragmentComponent = _fragment.default;
  _host.default.CompositeComponent = _composite.default; // Inject devtool hook

  _host.default.hook = hook || _hook.default; // Inject performance measurer

  _host.default.measurer = measurer; // Inject render driver

  if (!_host.default.driver) {
    if (!driver) {
      if (_universalEnv.isWeex) {
        driver = _driverWeex.default;
      } else if (_universalEnv.isWeb) {
        driver = _driverBrowser.default;
      } else {
        throw Error('No builtin driver matched');
      }
    }

    _host.default.driver = driver;
  }

  if (deviceWidth && _host.default.driver.setDeviceWidth) {
    _host.default.driver.setDeviceWidth(deviceWidth);
  }

  if (viewportWidth && _host.default.driver.setViewportWidth) {
    _host.default.driver.setViewportWidth(viewportWidth);
  }

  if (eventRegistry) {
    _host.default.driver.eventRegistry = eventRegistry;
  } // Body custom type only works in weex


  if (bodyType) {
    _host.default.driver.bodyType = bodyType;
  }

  if (bodyProps) {
    _host.default.driver.bodyProps = bodyProps;
  }
}

module.exports = exports["default"];